/*!
 * @file bad_pixels.h
 * @brief This file defines the BadPixels class
 * @author Tony Beville
 * @date 2012-10-03
 *
 * Copyright (C) 2012 Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef _FASTEC_CS_BADPIXELS_H_
#define _FASTEC_CS_BADPIXELS_H_

//--------------------------------------------------------------------
// Include files
//--------------------------------------------------------------------

#include <stdint.h>
#include <vector>

#include "sensor.h"

//--------------------------------------------------------------------
//! @brief The BadPixels class.
//--------------------------------------------------------------------

class BadPixels
{
public:
    typedef struct BAD_PIXEL
    {
        uint16_t    x;               //!< X coord of bad pixel.
        uint16_t    y;               //!< Y coord of bad pixel.
        uint8_t     offset;          //!< Correction offset.
    } BAD_PIXEL;

    BadPixels(SENSOR::SENSOR_BAD_PIXEL *sensor_bp_ptr);
    ~BadPixels();

    void set_roi(int true_x, int true_y, int w, int h);
    void correct();

private:
    std::vector<BAD_PIXEL> bad_pixels;  //!< The array of bad pixels.

    int roi_x;
    int roi_y;
    int roi_w;
    int roi_h;

    uint8_t calculate_offset(int index);
};

#endif /* !_FASTEC_CS_BADPIXELS_H_ */
