/*!
 * @file cs_socket.h
 * @brief This file defines the Camera Socket class.
 * @author Anthony L. Montiel
 * @date 2022-03-22
 *
 * Copyright (C) 2022 Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef CS_SOCKET_H_
#define CS_SOCKET_H_

//--------------------------------------------------------------------
// Include files
//--------------------------------------------------------------------

#ifdef _WIN32
#include <winsock.h>
#else
#include <sys/socket.h>
#include <sys/un.h>
#include <netinet/in.h>
#endif

#include <memory>

//--------------------------------------------------------------------
//! @brief The CsSocket class.
//--------------------------------------------------------------------
class CsSocket
{
public:
    typedef struct
    {
        int fd;
        union
        {
            struct sockaddr s;
            struct sockaddr_in sin;
            struct sockaddr_un sun;
        } u;
    } ADDR;

public:
    explicit CsSocket(sa_family_t family, __socket_type s_type) noexcept;
    CsSocket(const CsSocket& sock) noexcept;
    virtual ~CsSocket();

    std::unique_ptr<CsSocket> accept();
    bool bind(uint32_t ip_addr, uint16_t port);
    bool bind(const std::string& path);
    bool listen();

    ADDR& getAddr()     { return address; }
    int getFD()         { return address.fd; }
    bool getIPAddress(const std::string& if_name, ADDR& ip_addr);
    bool getMACAddress(const std::string& if_name, uint8_t *mac_addr);
    bool getSubNet(const std::string& if_name, ADDR& sn_addr);
    bool setInterface(const std::string& if_name);

private:
    ADDR address;       //!< Our address structure.
};

#endif /* CS_SOCKET_H_ */
