/*!
 * @file fan_proc.h
 * @brief Interface for coordinating access to the fan controller.
 *
 * Copyright 2017 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef __FAN_PROC_H__
#define __FAN_PROC_H__

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <iostream>

namespace FAN_PROC
{
//--------------------------------------------------------------------
// Constants, Typedefs and Macros
//--------------------------------------------------------------------

//! Organize all the statistics from the fan controller in one buffer.
typedef struct STATS_REQUEST
{
    double internal_temp_C; //!< Internal temperature, degrees C.
    double external_temp_C; //!< External temperature, degrees C.

    int tach_reading;       //!< The tachometer value read from the fan.
    int pwm_setting;        //!< Current PWM value being used by the fan.

} STATS_REQUEST;

} /* End of namespace FAN_PROC */

//--------------------------------------------------------------------
// Function Prototypes
//--------------------------------------------------------------------

extern void fan_init();
extern void fan_close();
extern void fan_control(bool stopFans);
extern uint32_t fan_get_status();

extern bool fan_get_temp(double *degrees_c_ptr);
extern void fan_set_temp(int degrees_c);
extern bool fan_get_stats(FAN_PROC::STATS_REQUEST *request);

extern void fan_dump(std::ostream& dump_stream);

#endif /* !__FAN_PROC_H__ */
