/*!
 * @file fcp.h
 *
 * @brief Header file which encapsulates the functionality of the
 *        Fastec Camera Control Protocol.
 *
 * Copyright 2010 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */
#ifndef __FASTEC_FCP_H__
#define __FASTEC_FCP_H__

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------

#include "cs_network.h"

//--------------------------------------------------------------------
// Constant, Typedef and Macros
//--------------------------------------------------------------------

// Path to the temporary file for the XML metadata file.
const char DOWNLOAD_XML_METADATA[] = ".config/Fastec/scratch/dnload.xml";
const char TEMP_PFMD_PATH[] = ".config/Fastec/scratch/pfmd.pm";

//--------------------------------------------------------------------
// Function Prototypes
//--------------------------------------------------------------------

// Register update functions.
extern int  fcp_autosave_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_update_lock_state(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_update_fastec_lock_state(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_update_stream_port_num(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_update_packet_size(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_ltr_mode_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_roi_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_sensor_gain_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t new_sensor_gain);
extern int  fcp_frame_rate_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_shutter_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_fpn_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_color_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_image_dest_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_low_light_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_lut_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_ss_frame_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_wb_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_matrix_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_marker_filter_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_preferences_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_session_length_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_sync_delay(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_syncin_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
extern int  fcp_syncout_update(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);

// GigE Parser
extern int  fcp_init(void);
extern void fcp_ltr_mode_init(void);
extern void fcp_validate_registers(void);
extern void fcp_validate_frame_limits(uint32_t frame_max);
extern int  fcp_init_regs(void);
extern void fcp_startup_notify(void);
extern int  fcp_exit(void);
extern void fcp_cleanup(void);
extern time_t fcp_get_lock_time();
extern time_t fcp_get_fastec_lock_time();
extern void fcp_lock_reset(void);
extern int  fcp_parse(CS_NETWORK::CS_NETWORK_MESSAGE *pmsg);
extern void fcp_reflect_fpn_state(void);
extern int  fcp_set_wb_preset(uint32_t wb_value);
extern void fcp_reset_save_limits(uint32_t new_max);
extern void fcp_limit_trigger_position(uint32_t new_frame_max);

// Information about the camera
extern void fcp_get_manufacture_name(char *name, int len);
extern void fcp_get_model_name(char *name, int len);
extern void fcp_get_device_version_name(char *ver, int len);
extern void fcp_get_manufacture_info(char *info, int len);
extern void fcp_get_serial_number(char *ser_num, int len);
extern void fcp_get_user_defined_name(char *name, int len);

// Notify any internal apps that something of importance has changed.
extern void fcp_notify_apps(uint32_t reg_addr, uint32_t reg_value);
extern int  fcp_stop_stream_thread(void);

// Utility system functions.
extern void fcp_system_reboot();
extern void fcp_system_restart();
extern void fcp_system_exit();

#endif /* __FASTEC_FCP_H__ */
