/*!
 * @file fi_display.h
 *
 * @brief
 *
 * Derived extensively from intel/libva-utils package.
 *
 * Copyright 2017 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FI_DISPLAY_H
#define FI_DISPLAY_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------

#include <string>
#include <va/va.h>

//--------------------------------------------------------------------
// Class Declaration
//--------------------------------------------------------------------

class FiDisplay
{
public:
    FiDisplay() { va_dpy = nullptr; }
    ~FiDisplay() {}

    virtual void closeDisplay() {}

    virtual VADisplay openDisplay() = 0;
    virtual VAStatus putSurface(VASurfaceID surface, const VARectangle *src_rect, const VARectangle *dst_rect) = 0;

    VADisplay getDisplay() { return va_dpy; }

protected:
    VADisplay va_dpy;
};

class FiDisplayX11 : public FiDisplay
{
public:
    FiDisplayX11();
    ~FiDisplayX11();

    void closeDisplay() override;

    virtual VADisplay openDisplay() override;
    virtual VAStatus putSurface(VASurfaceID surface, const VARectangle *src_rect, const VARectangle *dst_rect) override;

private:
    void doClose();
    bool ensureWindow(uint32_t width, uint32_t height);
    bool validateRect(const VARectangle *rect);

    void *x11_display;
    void *x11_window;
};

class FiDisplayWayland : public FiDisplay
{
public:
    FiDisplayWayland();
    ~FiDisplayWayland();

    void closeDisplay() override;

    virtual VADisplay openDisplay() override;
    virtual VAStatus putSurface(VASurfaceID surface, const VARectangle *src_rect, const VARectangle *dst_rect) override;

private:
    void doClose();
    bool ensureWindow();

    static void registry_handle_global(void *data, struct wl_registry *registry, uint32_t id, const char *interface, uint32_t version);

    static const std::string WL_COMPOSITOR;
    static const std::string WL_SHELL;

    static void *wayland_display;
    static const struct wl_registry_listener registry_listener;
};


class FiDisplayDRM : public FiDisplay
{
public:
    FiDisplayDRM();
    ~FiDisplayDRM();

    void closeDisplay() override;

    virtual VADisplay openDisplay() override;
    virtual VAStatus putSurface(VASurfaceID surface, const VARectangle *src_rect, const VARectangle *dst_rect) override;

private:
    void doClose();
    int drm_fd;
};

#endif /* FI_DISPLAY_H */
