/*!
 * @file fi_libva.h
 *
 * @brief
 *
 * Derived extensively from intel/libva-utils package.
 *
 * Copyright 2017 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef FI_LIBVA_H
#define FI_LIBVA_H

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------

#include <va/va.h>
#include <memory>
#include <mutex>

// Some versions of va.h don't support I420.
#ifndef VA_FOURCC_I420
#define VA_FOURCC_I420          0x30323449
#endif

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------
class FiDisplay;

//--------------------------------------------------------------------
// Class Declaration
//--------------------------------------------------------------------

/*!
 * @brief The FiLibVA class is the Fastec interface class providing support
 *        for the LibVA library.
 */
class FiLibVA
{
private:
    static std::unique_ptr<FiLibVA> instance;
    static std::mutex instance_mutex;

    /*!
     * @brief The FiLibVA's constructor is private to prevent direct construction calls.
     */
    FiLibVA();

public:
    ~FiLibVA();

    // FiLibVA should not be cloneable.
    FiLibVA(FiLibVA& other) = delete;

    // FiLibVA should not be assignable.
    void operator=(const FiLibVA&) = delete;

    /*!
     * This is the static method that controls the access to the FiLibVA
     * instance. On the first run, it creates a singleton object and places it
     * into the static field. On subsequent runs, it returns the client existing
     * object stored in the static field.
     */
    static FiLibVA *factory();

    VADisplay vaOpenDisplay();
    VADisplay vaOpenDRM();
    VADisplay vaGetDisplay();
    VADisplay vaGetDRM();
    void vaCloseDisplay();
    void vaCloseDRM();

    VAStatus vaPutDisplaySurface(VASurfaceID surface, const VARectangle *src_rect, const VARectangle *dst_rect);
    VAStatus vaPutDRMSurface(VASurfaceID surface, const VARectangle *src_rect, const VARectangle *dst_rect);

private:
    std::unique_ptr<FiDisplay> va_display;
    std::unique_ptr<FiDisplay> va_drm;
};

#endif /* FI_LIBVA_H */
