/*!
 * @file fsp.h
 * @brief This file defines the global interface to the Fastec
 *    Streaming Protocol (FSP) implementation.
 *
 * @author Anthony L. Montiel
 * @date 2012-02-16
 *
 * Copyright (C) 2012 Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef _FASTEC_STREAMING_PROTOCOL_H_
#define _FASTEC_STREAMING_PROTOCOL_H_

#include <stdint.h>

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------

namespace CS_NETWORK
{
struct CS_NETWORK_MESSAGE;
}

//--------------------------------------------------------------------
// External Prototypes
//--------------------------------------------------------------------

extern int fsp_control_update(CS_NETWORK::CS_NETWORK_MESSAGE *, uint32_t reg_value);
extern void fsp_disconnect();
extern void fsp_exit();
extern bool fsp_last_raw_image(uint8_t *image_data, int &image_len);
extern void fsp_set_download_file_retry(uint32_t retry_index);
extern int fsp_set_interframe_delay(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t frame_delay);
extern int fsp_set_inter_packet_delay(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t packet_delay);
extern int fsp_set_packet_size(uint32_t reg_value);
extern void fsp_set_save_path(const char *file_path, uint32_t file_len);
extern void fsp_set_stream_port_num(uint32_t reg_value);
extern void fsp_startup();

#endif /* !_FASTEC_STREAMING_PROTOCOL_H_ */
