/*!
 * @file grpc_server.h
 * @brief The declaration of the GrpcServer class interface.
 *
 * Copyright (C) 2023 RDI Technologies as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * RDI Technologies. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with RDI Technologies.
 */

#ifndef GRPC_SERVER_H_
#define GRPC_SERVER_H_

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <cstdint>

namespace GRPC_SERVER
{
//--------------------------------------------------------------------
// Constant, Typedefs and Macros
//--------------------------------------------------------------------

typedef struct GRPC_IMAGE
{
    uint32_t format;            //!< One of the GIGE_REG_STREAM_FORMAT values.
    int width;                  //!< Width of the image.
    int height;                 //!< Height of the image.
    uint32_t frame_num;         //!< Frame number for the image.
    int image_len;              //!< Number of bytes contained in the image data.
    uint8_t *image_data;        //!< The pointer to the image data.
    int header_len;             //!< Number of bytes contained in the image header data.
    uint8_t *header_data;       //!< The pointer to the image header data, may be nullptr.
} GRPC_IMAGE;

} /* End of namespace GRPC_SERVER */

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------

namespace CS_NETWORK { struct CS_NETWORK_MESSAGE; }

//--------------------------------------------------------------------
// Function Prototypes
//--------------------------------------------------------------------
extern int grpcServerInit();
extern int grpcServerClose();

extern bool grpcNotification(uint32_t reg_address, uint32_t reg_value);
extern int grpcSendMsg(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, std::uint32_t num_bytes);
extern bool grpcStreamIsConnected();
extern bool grpcStreamImage(const GRPC_SERVER::GRPC_IMAGE& image);

#endif /* GRPC_SERVER_H_ */
