/*!
 * @file ipm_proc.h
 * @brief Interface for coordinating access to and using the IPM.
 *
 * Copyright 2017 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef __IPM_PROC_H__
#define __IPM_PROC_H__

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <inttypes.h>
#include <ostream>

namespace IPM_PROC
{
//--------------------------------------------------------------------
// Constants, Typedefs and Macros
//--------------------------------------------------------------------

//! Organize all the input and output parameters for the IPM encoding
//! request into one structure.
struct IPM_REQUEST
{
    //! @name Input values.
    //! @{
    uint64_t image_addr;    //!< Address in Image Memory for the frame to encode.
    uint64_t dest_addr;     //!< [OPTIONAL] Address in Image Memory for processed image in image memory.
    uint32_t proc_info;     //!< IPM processing information.
    bool process_live;      //!< TRUE if we're supposed to process a live frame, FALSE otherwise.
    //
    //! @}

    //! @name Output values.
    //! @{
    uint32_t image_len;         //!< Length of processed image.
    uint64_t ipm_buf_addr;      //!< Buffer address for processed image in image memory.
    //
    //! @}
};

} /* End of namespace IPM_PROC */

//--------------------------------------------------------------------
// Function Prototypes
//--------------------------------------------------------------------

extern void ipm_proc_init();
extern void ipm_proc_close();
extern void ipm_proc_done();
extern void ipm_proc_reset();

extern void ipm_proc_dump(std::ostream& dump_stream);
extern void ipm_proc_release(uint64_t ipm_buffer);
extern bool ipmProcRequest(IPM_PROC::IPM_REQUEST *request);

#endif /* !__IPM_PROC_H__ */
