/*!
 * @file jpeg_util.h
 * @brief Wrappers for JPEG encoding.
 *
 * Copyright 2017 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef JPEG_UTIL_H__
#define JPEG_UTIL_H__

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------

#include <stdint.h>
#include <memory>
#include <va/va.h>

namespace JPEG_UTIL
{
//--------------------------------------------------------------------
// Constant Definitions
//--------------------------------------------------------------------

//! Pixel formats we support.
enum PIX_FORMAT
{
    I420,
    NV12,
    Y8,
    NONE
};

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------
struct _YUVComponentSpecs;
}

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------
class FiLibVA;
struct _VASurfaceAttrib;

//--------------------------------------------------------------------
// Class Declaration
//--------------------------------------------------------------------

class JpegUtil
{
public:
    JpegUtil();
    virtual ~JpegUtil();

    void set_pixel_format(int pixelFormat);
    int get_pixel_format() const;
    void set_quality(int quality);
    int get_quality() const;

    int encode(uint8_t *img_y, uint8_t *img_uv, int width, int height, uint8_t **enc_buf);
    void release(uint8_t *enc_buf);

private:
    int pixelFormat;
    int quality;
    int surface_type;

    std::unique_ptr<struct _VASurfaceAttrib> fourcc;
    std::unique_ptr<struct JPEG_UTIL::_YUVComponentSpecs> yuvComponent;

    bool init_compressor(VADisplay va_dpy, uint32_t& config_id);
};


#endif /* !JPEG_UTIL_H__ */
