/*!
 * @file lic_manager.h
 * @brief This is the header file for the license manager class.
 *
 * Copyright 2017 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef __LIC_MANAGER_H__
#define __LIC_MANAGER_H__

//--------------------------------------------------------------------
// Include Files
//--------------------------------------------------------------------
#include <stdio.h>
#include <stdint.h>

namespace LIC_MANAGER
{
//--------------------------------------------------------------------
// Constant Definitions
//--------------------------------------------------------------------

//! @name Possible values for ltr_mode
//! @{
const uint8_t LM_LTR_NONE = 0;  //!< LTR mode is not licensed
const uint8_t LM_LTR_ONLY = 1;  //!< LTR mode is licensed and is the only mode allowed
const uint8_t LM_LTR_DUAL = 2;  //!< Both LTR mode and normal mode are licensed
//! @}

//--------------------------------------------------------------------
// Forward Declarations
//--------------------------------------------------------------------
struct LIC_OPTIONS;

}

//--------------------------------------------------------------------
// Class declarations
//--------------------------------------------------------------------

class LicManager
{
public:
    // Disallow creating an instance of this object.
    LicManager();
    virtual ~LicManager();

public:
    virtual bool autoTrigger() const;
    virtual bool dvrPlayback() const;
    virtual bool integrated() const;
    virtual bool IRIG() const;
    virtual bool optical() const;
    virtual bool wireless() const;

    virtual uint32_t heightMax() const;
    virtual uint32_t widthMax() const;
    virtual uint32_t fpsLtrMax() const;
    virtual uint32_t fpsMax() const;
    virtual uint32_t ltrMode() const;
    virtual uint32_t memoryMax() const;
    virtual const char *model() const;
    virtual uint32_t ssdBandwidth() const;
    virtual uint32_t ssdMax() const;
    virtual const char *serial_no() const;

    virtual void licenseValidate();

protected:
    static std::string UNLICENSED;
    static std::string BAD_LICENSE;
    static std::string NO_SERIAL_NUMBER;

    void defaultOptions(LIC_MANAGER::LIC_OPTIONS *options);
    bool signatureCheck();

    void getDefaultModel(LIC_MANAGER::LIC_OPTIONS *options);
    bool licenseParse(LIC_MANAGER::LIC_OPTIONS *options, FILE *lic_file);
    bool licenseRead(LIC_MANAGER::LIC_OPTIONS *options);

    virtual int revCompare(const char *a, const char *b);
};

#endif /* __LIC_MANAGER_H__ */
