/*!
 * @file override.h
 * @brief Override parameters from file for debug.
 *
 * Copyright 2013 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef OVERRIDE_H
#define OVERRIDE_H

#include <stdint.h>
#include <string>

namespace FI_OVERRIDE
{
//--------------------------------------------------------------------
// Constant, Typedefs and Macros
//--------------------------------------------------------------------

//--------------------------------------------------------------------
// Variable declarations
//--------------------------------------------------------------------

#define OVR_LOGGING             (1 << 0)    // bool logging - turn on extra logging
#define OVR_FRAMERATE           (1 << 1)    // u32 framerate - frames per second
#define OVR_INTEGRATION         (1 << 2)    // u32 integration - clocks
#define OVR_SEQMODE3            (1 << 3)    // u32 Lupa 1300 SEQMODE3 register
#define OVR_ROI_WIDTH           (1 << 4)    // u32 width, in pixels, of the ROI to use.
#define OVR_ROI_HEIGHT          (1 << 5)    // u32 height, in rows, of the ROI to use.
#define OVR_ROI_X_OFFSET        (1 << 6)    // u32 x-offset for the ROI, in pixels.
#define OVR_ROI_Y_OFFSET        (1 << 7)    // u32 y-offset for the ROI.
#define OVR_BIT_SELECT          (1 << 8)    // u32 10-bit (8) or hi- (4), mid- (2), lo- (1) byte select.
#define OVR_CORRECTION_MODE     (1 << 9)    // bool Pixel correction mode: FPN (1), Column (0).
#define OVR_FSP_PKT_DELAY       (1 << 10)   // u32 FSP inter-packet delay (microseconds)
#define OVR_FSP_FRAME_DELAY     (1 << 11)   // u32 FSP inter-frame delay (milliseconds)
#define OVR_STATIC_IP_ADDR      (1 << 12)   // u32 Static IP address to use.
#define OVR_STATIC_NET_MASK     (1 << 13)   // u32 Static Network Mask to use.
#define OVR_STATIC_GATEWAY      (1 << 14)   // u32 Static Gateway IP address to use.
#define OVR_SATA_REQ_SIZE       (1 << 15)   // u32 dma request size for SATA DMA writes
#define OVR_SATA_TIMER_PERIOD   (1 << 16)   // u32 dma timer period, 0 to disable timer
#define OVR_SATA_MAX_SECTORS    (1 << 17)   // u32 maximum number of sectors per write
#define OVR_OVERPROVISION_PCT   (1 << 18)   // u32 percent overprovisioning
#define OVR_WHITE_BALANCE_NORM  (1 << 19)   // bool apply white balance normalization
#define OVR_LOG_SSD_RESPONSE    (1 << 20)   // bool do logging of ssd response times
#define OVR_SECURE_ERASE_ONLY   (1 << 21)   // bool SECURITY ERASE even if ssd does BLOCK ERASE
#define OVR_DISABLE_CSI         (1 << 22)   // bool disable CSI DMA for memory bandwidth tests
#define OVR_STREAM_RAW          (1 << 23)   // bool stream TIFF RAW instead of JPEGs for live view.
#define OVR_FAN_TEMPERATURE     (1 << 24)   // bool override the FPGA fan temperature.
#define OVR_UPDATE_SERVER       (1 << 25)   // string override the update servier URL.
#define OVR_FFLR_SESS_SIZE      (1 << 26)   // u32 FasFireLR session size, in MiB. So 4GiB would be "4096" MiB.

#ifdef INCLUDE_ALCON_VARS
#define OVR_ALCON_EXT_TRIG_POL  (1 << 24)   // bool (Alcon) Ext. Trig polarity: High (1), Low (0)
#define OVR_ALCON_SYNC_OUT_POL  (1 << 25)   // bool (Alcon) Sync Output polarity: High (1), Low (0)
#define OVR_ALCON_MODE      (1 << 26)   // bool (Alcon) force Alcon mode of operation
#define OVR_ALCON_BURST_LEN     (1 << 27)   // u32 (Alcon) capture burst length.
#define OVR_ALCON_MAC_ADDR  (1 << 28)   // u32 (Alcon) ACC MAC address.
#define OVR_ALCON_IP_ADDR   (1 << 29)   // u32 (Alcon) ACC IP address.
#define OVR_ALCON_PORT      (1 << 30)   // u32 (Alcon) ACC IP port for packets.
#define OVR_ALCON_MAX_MTU   (1 << 31)   // u32 (Alcon) Maximum Ethernet MTU.
#endif /* INCLUDE_ALCON_VARS */
} /* End of namespace FI_OVERRIDE */

//--------------------------------------------------------------------
// Function prototypes
//--------------------------------------------------------------------

bool override_init(void);
bool override_u32(uint32_t which, uint32_t *p_value);
bool override_bool(uint32_t which, bool *p_value);
bool override_u8a(uint32_t flag, uint8_t **p_rtn);
bool override_string(uint32_t flag, std::string& rtn_str);

//--------------------------------------------------------------------
// Inline functions
//--------------------------------------------------------------------

#endif // OVERRIDE_H

