/*!
 * @file save_proc.h
 * @brief Interface for threaded image processing.
 *
 * Copyright 2017 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef __SAVE_PROC_H__
#define __SAVE_PROC_H__

//--------------------------------------------------------------------
// Includes
//--------------------------------------------------------------------
#include <string>
#include <image_format.h>

#include <fastec/fas_video.h>
#include <fastec/fi_stream.h>

namespace SAVE_PROC
{
//--------------------------------------------------------------------
// Constants, Typedefs and Macros
//--------------------------------------------------------------------

//! Organize all the input and output parameters for the save processing
//! request into one structure.
typedef struct SAVE_REQUEST
{
    uint32_t start_frame;       //!< Starting (inclusive) frame for the save.
    uint32_t end_frame;         //!< Ending (inclusive) frame for the save.

    bool ltr_mode;              //!< True if we're in LTR mode.
    uint32_t proc_info;         //!< IPM processing information.
    uint32_t dma_mod;           //!< DMA specific information.
    uint32_t image_height;      //!< Height of image, in rows.  /* fiv_dma_height */
    uint32_t image_width;       //!< Width of image, in pixels. /* fiv_dma_width */

    //! If we're creating a video, we need a stream writer.
    std::weak_ptr<FAS_VIDEO::FiVideoStream> video_writer;
    uint32_t video_codec;       //!< The video codec being used (i.e. JPEG, BMP, Planar).
    FAS_INTERNAL::FIP_HANDLE pack_handle; //!< Handle to the packed streamer.

    std::string path_str;       //!< Everything to build the filename except the frame number.
    uint32_t header_len;        //!< Number of bytes in the header.
    const uint8_t *header_ptr;  //!< The image header, if any.

    bool do_subfolders;         //!< True if we're doing subfolders.
    int subfolder_count;        //!< If we have too many images, we need to break into subfolders.

    bool using_sharedmem;       //!< Flag indicating if we're supposed to use the shared memory ring buffer.

    IMAGE_FORMAT::IMG_PROCESSING_INFO *info_ptr;  //!< Allows us to pass progress back to the caller.
} SAVE_REQUEST;

} /* End of namespace SAVE_PROC */

//--------------------------------------------------------------------
// Function Prototypes
//--------------------------------------------------------------------

extern void saveProcInit();
extern void saveProcClose();

extern void saveProcCancel();

extern void saveProcDump(std::ostream& dump_stream);
extern int saveProcRequest(SAVE_PROC::SAVE_REQUEST *request);

#endif /* !__SAVE_PROC_H__ */
