/*!
 * @file telemetry.h
 * @brief This file defines the telemetry access class.
 * @author Anthony L. Montiel
 * @date 2018-06-11
 *
 * Copyright (C) 2018 Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef _FASTEC_TELEMETRY_H_
#define _FASTEC_TELEMETRY_H_

//--------------------------------------------------------------------
// Include Files
//--------------------------------------------------------------------
#include <memory>
#include <mutex>
#include <string>
#include <json/json.h>

#include "cs_network.h"

//--------------------------------------------------------------------
// Telemetry class declaration
//--------------------------------------------------------------------

class telemetry
{
private:
    // This is a singleton object.
    telemetry();

    double get_em2120_reading(int reg_addr, bool mantissa_only = false);
    bool get_fan_stats(Json::Value& dev_tree);
    double get_fan_temperature();
    double get_firefly_voltage();
    bool get_power_good();

    static std::unique_ptr<telemetry> instance;
    static std::mutex instance_mutex;

public:
    ~telemetry();

    // Singletons should not be cloneable.
    telemetry(telemetry& other) = delete;

    // Singletons should not be assignable.
    void operator=(const telemetry&) = delete;

    static telemetry *factory();

    static uint32_t get_json(char *dest_ptr, uint32_t max_len);
    static int get_nvme_temp();
    static double get_em2120_temperature();
    static double get_fpga_internal_temp();
    static double get_fpga_temperature();
    static double get_firefly_temperature();
    static double get_plx_temperature();

    static int set_adc_channel(CS_NETWORK::CS_NETWORK_MESSAGE *p_msg, uint32_t reg_value);
};

#endif /* !_FASTEC_TELEMETRY_H_ */

