/*!
 * @file wb_file.h
 * @brief This file defines interface to the white balance functions.
 * @author Anthony L. Montiel
 * @date 2016-02-24
 *
 * Copyright (C) 2016 Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#ifndef _WB_FILE_H
#define _WB_FILE_H

//--------------------------------------------------------------------
// Constant, Typedef and Macros
//--------------------------------------------------------------------

// White balance gains and matrix coefficients to use.
typedef struct _WBAL_GAINS
{
    // First the gains.
    uint16_t    red;
    uint16_t    green;
    uint16_t    blue;

    // Now the matrix coefficients.
    uint16_t    matrix_red1;
    uint16_t    matrix_red2;
    uint16_t    matrix_red3;
    uint16_t    matrix_grn1;
    uint16_t    matrix_grn2;
    uint16_t    matrix_grn3;
    uint16_t    matrix_blu1;
    uint16_t    matrix_blu2;
    uint16_t    matrix_blu3;

    uint32_t    as_shot_red;
    uint32_t    as_shot_grn;
    uint32_t    as_shot_blu;

    uint32_t    dc_offset_red;
    uint32_t    dc_offset_grn;
    uint32_t    dc_offset_blu;
} WBAL_GAINS;

//--------------------------------------------------------------------
// Function Prototypes
//--------------------------------------------------------------------

extern int  load_wb_file(Sensor *sensor_ptr);
extern uint8_t  get_wb_option(pm_metadata *pm);
extern const WBAL_GAINS *get_wb(int wb_value);

#endif /* !_WB_FILE_H */

